Changelog
=========

0.0.4 (2020-06-09)
------------------

- added option for specifying the width of the banner (`-w`, `--width`)
- added option to list available fonts (`-L`, `--list_fonts`)
- added option to output information about font (`-F`, `--print_font_info`)


0.0.3 (2020-06-09)
------------------

- added ability to add a subtitle (placeholder `{SUBTITLE}`) using `-s, --subtitle`,
  which can be used for a version number
- added `-i, --print_templates` option to output templates and the supported placeholders


0.0.2 (2020-06-07)
------------------

- fixed entry point of console script


0.0.1 (2020-06-07)
------------------

- initial release
